@@ -9,26 +9,23 @@ if (base::getRversion() >= "2.15.1") {
 #' the acs's api.key.install function.  Census API keys can be obtained at http://www.census.gov/developers/tos/key_request.html.
 #'
 #' @param tableId The id of an ACS table
-#' @param lod A string indicating the level of detail of the map.  Must be "state", "county" or "zip".
-#' @param num_buckets The number of equally sized buckets to places the values in.  A value of 1 
-#' will use a continuous scale, and a value in [2, 9] will use that many buckets.  For
-#' example, 2 will show values above or below the median, and 9 will show the maximum
-#' resolution.  Defaults to 9.
-#' @param showLabels For state choropleths, whether or not to show state abbreviations on the map.
-#' Defaults to T. 
-#' @param states A vector of states to render.  Defaults to state.abb.
+#' @param map A string indicating which map the data is for.  Must be "state", "county" or "zip".
 #' @param endyear The end year of the survey to use.  See acs.fetch (?acs.fetch) and http://1.usa.gov/1geFSSj for details.
 #' @param span The span of time to use.  See acs.fetch and http://1.usa.gov/1geFSSj for details.
-#' @param renderAsInsets If true, Alaska and Hawaii will be rendered as insets on the map.  If false, all 50 states will be rendered
 #' on the same longitude and latitude map to scale. This variable is only checked when the "states" variable is equal to all 50 states.
+#' @param buckets The number of equally sized buckets to places the values in.  A value of 1 
+#' will use a continuous scale, and a value in [2, 9] will use that many buckets. 
+#' @param zoom An optional list of states to zoom in on. Must come from the "name" column in
+#' ?state.regions.
 #' @return A choropleth.
 #' 
 #' @keywords choropleth, acs
 #' 
-#' @seealso \code{\link{choroplethr}} which this function wraps
 #' @seealso \code{api.key.install} in the acs package which sets an Census API key for the acs library
 #' @seealso http://factfinder2.census.gov/faces/help/jsf/pages/metadata.xhtml?lang=en&type=survey&id=survey.en.ACS_ACS 
 #' which contains a list of all ACS surveys.
+#' @references Uses the acs package created by Ezra Haber Glenn.
+
 #' @export
 #' @examples
 #' \dontrun{
@@ -36,22 +33,28 @@ if (base::getRversion() >= "2.15.1") {
 #' choroplethr_acs("B01003", "state")
 #' 
 #' # median income, continuous scale, counties in New York, New Jersey and Connecticut
-#' choroplethr_acs("B19301", "county", num_buckets=1, states=c("NY", "NJ", "CT"))
+#' choroplethr_acs("B19301", "county", buckets=1, zoom=c("new york", "new jersey", "connecticut"))
 #'
 #' # median income, all zip codes
 #' choroplethr_acs("B19301", "zip") } 
 #' @importFrom acs acs.fetch geography estimate geo.make
-choroplethr_acs = function(tableId, lod, num_buckets = 9, showLabels = T, states = state.abb, endyear = 2011, span = 5, renderAsInsets=TRUE)
+choroplethr_acs = function(tableId, map, endyear=2011, span=5, buckets=7, zoom=NULL)
 {
-  stopifnot(lod %in% c("state", "county", "zip"))
-  stopifnot(num_buckets > 0 && num_buckets < 10)
+  stopifnot(map %in% c("state", "county", "zip"))
+  stopifnot(buckets > 0 && buckets < 10)
   
-  acs.data   = acs.fetch(geography=make_geo(lod), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
+  acs.data   = acs.fetch(geography=make_geo(map), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
   column_idx = get_column_idx(acs.data, tableId) # some tables have multiple columns 
   title      = acs.data@acs.colnames[column_idx] 
-  acs.df     = make_df(lod, acs.data, column_idx) # choroplethr requires a df
-  acs.df$region = as.character(acs.df$region) # not a factor
-  choroplethr(acs.df, lod, num_buckets, title, "", showLabels, states=states, renderAsInsets=renderAsInsets);  
+  acs.df     = make_df(map, acs.data, column_idx) # choroplethr requires a df
+  
+  if (map=="state") {
+    state_choropleth(acs.df, title, "", buckets, zoom)
+  } else if (map=="county") {
+    county_choropleth(acs.df, title, "", buckets, zoom)
+  } else if (map=="zip") {
+    zip_map(acs.df, title, "", buckets, zoom)
+  }
 }
 
 #' Returns a data.frame representing American Community Survey estimates.
@@ -60,7 +63,7 @@ choroplethr_acs = function(tableId, lod, num_buckets = 9, showLabels = T, states
 #' acs's api.key.install function.  Census API keys can be obtained at http://www.census.gov/developers/tos/key_request.html.
 #'
 #' @param tableId The id of an ACS table.
-#' @param lod The level of geographic detail for the data.frame.  Must be one of "state", "county" or "zip". 
+#' @param map The map you want the data to match. Must be one of "state", "county" or "zip". 
 #' @param endyear The end year of the survey.  Defaults to 2012.
 #' @param span The span of the survey.  Defaults to 5.
 #' @param column_idx An optional column index to specify.
@@ -72,40 +75,30 @@ choroplethr_acs = function(tableId, lod, num_buckets = 9, showLabels = T, states
 #' \dontrun{
 #' library(Hmisc) # for cut2
 #' # States with greater than 1M residents
-#' df     = get_acs_df("B01003", "state") # population
-#' df.map = bind_df_to_map(df, "state")
-#' df.map$value = cut2(df.map$value, cuts=c(0,1000000,Inf))
-#' render_choropleth(df.map, "state", "States with a population over 1M", "Population")
+#' df       = get_acs_df("B01003", "state") # population
+#' df$value = cut2(df$value, cuts=c(0,1000000,Inf))
+#' state_choropleth(df, title="States with a population over 1M", legend="Population")
 #'
 #' # Counties with greater than or greater than 1M residents
-#' df     = get_acs_df("B01003", "county") # population
-#' df.map = bind_df_to_map(df, "county")
-#' df.map$value = cut2(df.map$value, cuts=c(0,1000000,Inf))
-#' render_choropleth(df.map, "county", "Counties with a population over 1M", "Population")
+#' df       = get_acs_df("B01003", "county") # population
+#' df$value = cut2(df$value, cuts=c(0,1000000,Inf))
+#' county_choropleth(df, title="Counties with a population over 1M", legend="Population")
 #' 
 #' # ZIP codes in California where median age is between 20 and 30
 #' df       = get_acs_df("B01002", "zip") # median age
 #' df       = df[df$value >= 20 & df$value <= 30, ]
 #' df$value = cut2(df$value, g=3) # 3 equally-sized groups
-#' df.map   = bind_df_to_map(df, "zip")
-#' render_choropleth(df.map, 
-#'                  "zip", 
-#'                  title = "CA Zip Codes by Age",
-#'                  scaleName = "Median Age",
-#'                  states = "CA") 
+#' zip_map(df, title="CA Zip Codes by Age", legend="Median Age", zoom="california")
 #' }
-get_acs_df = function(tableId, lod, endyear=2012, span=5, column_idx = -1)
+get_acs_df = function(tableId, map, endyear=2012, span=5, column_idx = -1)
 {
-  stopifnot(lod %in% c("state", "county", "zip"))
+  stopifnot(map %in% c("state", "county", "zip"))
   
-  acs.data   = acs.fetch(geography=make_geo(lod), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
+  acs.data   = acs.fetch(geography=make_geo(map), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
   if (column_idx == -1) {
     column_idx = get_column_idx(acs.data, tableId) # some tables have multiple columns 
   }
-  acs.df     = make_df(lod, acs.data, column_idx) # turn into df
-  acs.df$region = as.character(acs.df$region)
-  
-  acs.df
+  make_df(map, acs.data, column_idx) # turn into df
 }
 
 # support multiple column tables
@@ -121,58 +114,42 @@ get_column_idx = function(acs.data, tableId)
   column_idx
 }
 
-#' Returns the column names of an ACS table.
-#' 
-#' @param tableId The id of an ACS table.
-#' @param lod The level of geographic detail for the data.frame.  Must be one of "state", "county" or "zip". 
-#' @param endyear The end year of the survey.  Defaults to 2012.
-#' @param span The span of the survey.  Defaults to 5.
-#' @return A vector of column names 
-#' @export
-#' @seealso http://factfinder2.census.gov/faces/help/jsf/pages/metadata.xhtml?lang=en&type=survey&id=survey.en.ACS_ACS, which lists all ACS Surveys.
-#' @importFrom acs acs.fetch geography estimate geo.make
-get_acs_column_names = function(tableId, lod, endyear=2012, span=5)
+make_geo = function(map)
 {
-  stopifnot(lod %in% c("state", "county", "zip"))
-  stopifnot(span %in% c(1, 3, 5))
-  
-  acs.data = acs.fetch(geography=make_geo(lod), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
-  acs.data@acs.colnames
-}
-
-make_geo = function(lod)
-{
-  stopifnot(lod %in% c("state", "county", "zip"))
-  if (lod == "state") {
+  stopifnot(map %in% c("state", "county", "zip"))
+  if (map == "state") {
     geo.make(state = "*")
-  } else if (lod == "county") {
+  } else if (map == "county") {
     geo.make(state = "*", county = "*")
   } else {
     geo.make(zip.code = "*")
   }
 }
 
-make_df = function(lod, acs.data, column_idx) 
+make_df = function(map, acs.data, column_idx) 
 {
-  stopifnot(lod %in% c("state", "county", "zip"))
+  stopifnot(map %in% c("state", "county", "zip"))
   
-  if (lod == "state") {
-    data.frame(region = geography(acs.data)$NAME, 
-               value  = as.numeric(estimate(acs.data[,column_idx])));
-  } else if (lod == "county") {
+  if (map == "state") {
+    df = data.frame(region = tolower(geography(acs.data)$NAME), 
+                    value  = as.numeric(estimate(acs.data[,column_idx])));
+    df[df$region != "puerto rico", ]
+  } else if (map == "county") {
     # create fips code
     acs.data@geography$fips = paste(as.character(acs.data@geography$state), 
                                     acs.data@geography$county, 
-                                    sep = "");
+                                    sep = "")
     # put in format for call to all_county_choropleth
-    data.frame(region = geography(acs.data)$fips, 
-               value  = as.numeric(estimate(acs.data[,column_idx])));
-    
-  } else if (lod == "zip") {
+    acs.data@geography$fips = as.numeric(acs.data@geography$fips)
+    df = data.frame(region = geography(acs.data)$fips, 
+                    value  = as.numeric(estimate(acs.data[,column_idx])));
+    # remove state fips code 72, which is Puerto Rico, which we don't map
+    df[df$region < 72000 | df$region > 72999, ]     
+  } else if (map == "zip") {
     # put in format for call to choroplethr
     acs.df = data.frame(region = geography(acs.data)$zipcodetabulationarea, 
                         value  = as.numeric(estimate(acs.data[,column_idx])))
     
     na.omit(acs.df) # surprisingly, this sometimes returns NA values
   }
-}
+}
\ No newline at end of file
