@@ -26,6 +26,6 @@ library(ggplot2)
 
 choro = ZipMap$new(df_pop_zip)
 choro$title = "2012 Population Estimates"
-choro$ggplot_scale = scale_color_brewer(name="Population", palette=2)
+choro$ggplot_scale = scale_color_brewer(name="Population", palette=2, drop=FALSE)
 choro$render()
 
